# Chromium crypto

Reference:

- [chromium linux](https://source.chromium.org/chromium/chromium/src/+/main:components/os_crypt/sync/os_crypt_linux.cc)
- [chromium mac](https://source.chromium.org/chromium/chromium/src/+/main:components/os_crypt/sync/os_crypt_mac.mm)
- [chromium win](https://source.chromium.org/chromium/chromium/src/+/main:components/os_crypt/sync/os_crypt_win.cc)
- [chromium win appbound](https://source.chromium.org/chromium/chromium/src/+/main:chrome/browser/os_crypt/app_bound_encryption_provider_win.cc;l=40)
- [decrypt_chrome_v20_cookie.py](https://github.com/runassu/chrome_v20_decryption/blob/main/decrypt_chrome_v20_cookie.py)
- [Windows Impersonate](https://github.com/thewh1teagle/rookie/blob/main/rookie-rs/src/windows/appbound/impersonate.rs)
